@@ -1,16 +1,16 @@
 <?php
 /**
- * $Horde: kronolith/index.php,v 1.28 2004/10/19 10:09:11 jan Exp $
+ * $Horde: kronolith/index.php,v 1.28.10.3 2009-01-06 15:24:43 jan Exp $
  *
- * Kronolith: Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL). If you did
+ * See the enclosed file COPYING for license information (GPL). If you
  * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
  */
 
 @define('KRONOLITH_BASE', dirname(__FILE__));
-$kronolith_configured = (@is_readable(KRONOLITH_BASE . '/config/conf.php') &&
-                         @is_readable(KRONOLITH_BASE . '/config/prefs.php'));
+$kronolith_configured = (is_readable(KRONOLITH_BASE . '/config/conf.php') &&
+                         is_readable(KRONOLITH_BASE . '/config/prefs.php'));
 
 if (!$kronolith_configured) {
     require KRONOLITH_BASE . '/../lib/Test.php';
