@@ -1,18 +1,19 @@
 <?php
 
-$block_name = _("Month View");
+$block_name = _("This Month");
 
 /**
  * Horde_Block_Kronolith_month:: Implementation of the Horde_Block API
  * to display a mini month view of calendar items.
  *
- * $Horde: kronolith/lib/Block/month.php,v 1.21.2.3 2005/05/10 04:03:02 chuck Exp $
+ * $Horde: kronolith/lib/Block/month.php,v 1.21.2.13 2009-06-18 17:31:03 jan Exp $
  *
  * @package Horde_Block
  */
 class Horde_Block_Kronolith_month extends Horde_Block {
 
     var $_app = 'kronolith';
+    var $_share = null;
 
     function _params()
     {
@@ -37,12 +38,20 @@ class Horde_Block_Kronolith_month extends Horde_Block {
     function _title()
     {
         global $registry;
+        require_once dirname(__FILE__) . '/../base.php';
 
-        $title = strftime('%B, %Y');
-        $html  = Horde::link(Horde::url($registry->getInitialPage(), true), $title) . $title . '</a> :: ';
-        $html .= Horde::link(Horde::applicationUrl('addevent.php', true), _("New Event")) . Horde::img('new.png', _("New Event"), '', Horde::url($registry->getImageDir(), true, -1)) . ' ' . _("New Event") . '</a>';
-
-        return $html;
+        $title = _("All Calendars");
+        if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+            $this->_share = &$GLOBALS['kronolith_shares']->getShare($this->_params['calendar']);
+            if (!is_a($this->_share, 'PEAR_Error')) {
+                $url_params = array('display_cal' => $this->_params['calendar']);
+                $title = htmlspecialchars($this->_share->get('name'));
+            }
+        } else {
+            $url_params = array();
+        }
+        
+        return $title . ', ' . Horde::link(Horde::url(Util::addParameter($registry->getInitialPage(), $url_params), true)) . strftime('%B, %Y') . '</a>';
     }
 
     /**
@@ -56,15 +65,27 @@ class Horde_Block_Kronolith_month extends Horde_Block {
         require_once dirname(__FILE__) . '/../base.php';
         require_once KRONOLITH_BASE . '/lib/Day.php';
 
+        if ($this->_params['calendar'] != '__all') {
+            if (empty($this->_share)) {
+                $this->_share = $GLOBALS['kronolith_shares']->getShare($this->_params['calendar']);
+            }
+            if (is_a($this->_share, 'PEAR_Error')) {
+                return $this->_share;
+            }
+            if (!$this->_share->hasPermission(Auth::getAuth(), PERMS_SHOW)) {
+                return _("Permission Denied");
+            }
+        }
+
         Horde::addScriptFile('tooltip.js', 'horde', true);
 
         $year = date('Y');
         $month = date('m');
         $today = mktime(0, 0, 0, date('n'), date('j'), date('Y'));
 
-        $startday = &new Horde_Date(array('mday' => 1,
-                                          'month' => $month,
-                                          'year' => $year));
+        $startday = new Horde_Date(array('mday' => 1,
+                                         'month' => $month,
+                                         'year' => $year));
         $startday = $startday->dayOfWeek();
         $daysInView = Date_Calc::weeksInMonth($month, $year) * 7;
         if (!$prefs->getValue('week_start_monday')) {
@@ -75,9 +96,9 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             if ($startday == HORDE_DATE_SUNDAY) {
                 $daysInView -= 7;
             }
-            $endday = &new Horde_Date(array('mday' => Horde_Date::daysInMonth($month, $year),
-                                            'month' => $month,
-                                            'year' => $year));
+            $endday = new Horde_Date(array('mday' => Horde_Date::daysInMonth($month, $year),
+                                           'month' => $month,
+                                           'year' => $year));
             $endday = $endday->dayOfWeek();
             if ($endday == HORDE_DATE_SUNDAY) {
                 $daysInView += 7;
@@ -90,20 +111,14 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             }
         }
 
-        $startDate = &new Horde_Date(array('year' => $year,
-                                           'month' => $month,
-                                           'mday' => $startOfView));
-        $endDate = &new Horde_Date(array('year' => $year,
-                                         'month' => $month,
-                                         'mday' => $startOfView + $daysInView,
-                                         'hour' => 23,
-                                         'min' => 59,
-                                         'sec' => 59));
+        $startDate = new Horde_Date(array('year' => $year, 'month' => $month, 'mday' => $startOfView));
+        $endDate = new Horde_Date(array('year' => $year, 'month' => $month, 'mday' => $startOfView + $daysInView,
+                                        'hour' => 23, 'min' => 59, 'sec' => 59));
         $startDate->correct();
         $endDate->correct();
 
         /* Table start. and current month indicator. */
-        $html = '<table cellspacing="1" class="block-monthgrid" width="100%">';
+        $html = '<table cellspacing="1" class="block-monthgrid" width="100%"><tr>';
 
         /* Set up the weekdays. */
         $weekdays = array(_("Mo"), _("Tu"), _("We"), _("Th"), _("Fr"), _("Sa"));
@@ -117,22 +132,30 @@ class Horde_Block_Kronolith_month extends Horde_Block {
         }
 
         if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
-            $all_events = Kronolith::listEvents($startDate, $endDate, array($this->_params['calendar']));
+            $all_events = Kronolith::listEvents(
+                $startDate,
+                $endDate,
+                array($this->_params['calendar']), true, false, false);
         } else {
-            $all_events = Kronolith::listEvents($startDate, $endDate, $GLOBALS['display_calendars']);
+            $all_events = Kronolith::listEvents($startDate,
+                                                $endDate,
+                                                $GLOBALS['display_calendars']);
+        }
+        if (is_a($all_events, 'PEAR_Error')) {
+            return '<em>' . $all_events->getMessage() . '</em>';
         }
 
         $weeks = array();
         $weekday = 0;
         $week = -1;
-        for ($day = $startOfView; $day < $startOfView + $daysInView; $day++) {
+        for ($day = $startOfView; $day < $startOfView + $daysInView; ++$day) {
             $dayStamp = mktime(0, 0, 0, $month, $day, $year);
 
             if ($weekday == 7) {
                 $weekday = 0;
             }
             if ($weekday == 0) {
-                $week++;
+                ++$week;
                 $html .= '</tr><tr>';
             }
 
@@ -147,18 +170,27 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             }
             $html .= '<td align="center" class="' . $td_class . '">';
 
+            $url_params = array('timestamp' => $dayStamp);
+            if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+                $url_params['display_cal'] = $this->_params['calendar'];
+            }
             /* Set up the link to the day view. */
             $url = Horde::applicationUrl('day.php', true);
-            $url = Util::addParameter($url, array('timestamp' => $dayStamp));
+            $url = Util::addParameter($url, $url_params);
 
             if (!empty($all_events[$dayStamp])) {
                 /* There are events; create a cell with tooltip to
                  * list them. */
                 $day_events = '';
                 foreach ($all_events[$dayStamp] as $event) {
-                    $day_events .= date($prefs->getValue('twentyFour') ? 'G:i' : 'g:ia', $event->start->timestamp()) . ' - ' . date($prefs->getValue('twentyFour') ? 'G:i' : 'g:ia', $event->end->timestamp());
-                    $day_events .= ($event->getLocation()) ? ' (' . $event->getLocation() . ')' : '';
-                    $day_events .= ' ' . $event->getTitle() . "\n";
+                    if ($event->isAllDay()) {
+                        $day_events .= _("All day");
+                    } else {
+                        $day_events .= $event->start->strftime($prefs->getValue('twentyFour') ? '%R' : '%I:%M%p') . '-' . $event->end->strftime($prefs->getValue('twentyFour') ? '%R' : '%I:%M%p');
+                    }
+                    $day_events .= ':'
+                        . (($event->getLocation()) ? ' (' . $event->getLocation() . ')' : '')
+                        . ' ' . $event->getTitle() . "\n";
                 }
                 $cell = Horde::linkTooltip($url, _("View Day"), '', '', '', $day_events) . date('j', $dayStamp) . '</a>';
             } else {
@@ -168,11 +200,11 @@ class Horde_Block_Kronolith_month extends Horde_Block {
 
             /* Bold the cell if there are events. */
             if (!empty($all_events[$dayStamp])) {
-                $cell = '<b>' . $cell . '</b>';
+                $cell = '<strong>' . $cell . '</strong>';
             }
 
             $html .= $cell . '</td>';
-            $weekday++;
+            ++$weekday;
         }
 
         return $html . '</tr></table>';
