@@ -6,7 +6,7 @@ $block_name = _("Prior Events");
  * Horde_Block_Kronolith_monthlist:: Implementation of the Horde_Block
  * API to display a list of previous calendar items grouped by month.
  *
- * $Horde: kronolith/lib/Block/prevmonthlist.php,v 1.15.2.10 2008/08/31 17:10:49 mrubinsk Exp $
+ * $Horde: kronolith/lib/Block/prevmonthlist.php,v 1.15.2.14 2009-01-13 22:44:45 mrubinsk Exp $
  *
  * @package Horde_Block
  */
@@ -39,7 +39,12 @@ class Horde_Block_Kronolith_prevmonthlist extends Horde_Block {
      */
     function _title()
     {
-        return Horde::link(Horde::url($GLOBALS['registry']->getInitialPage(), true)) . _("Prior Events") . '</a>';
+        if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+            $url_params = array('display_cal' => $this->_params['calendar']);
+        } else {
+            $url_params = array();
+        }
+        return Horde::link(Horde::url(Util::addParameter($GLOBALS['registry']->getInitialPage(), $url_params), true)) . _("Prior Events") . '</a>';
     }
 
     /**
@@ -69,7 +74,7 @@ class Horde_Block_Kronolith_prevmonthlist extends Horde_Block {
             if (!is_a($calendar, 'PEAR_Error') && !$calendar->hasPermission(Auth::getAuth(), PERMS_SHOW)) {
                 return _("Permission Denied");
             }
-            $all_events = Kronolith::listEvents($startDate, $endDate, array($this->_params['calendar']));
+            $all_events = Kronolith::listEvents($startDate, $endDate, array($this->_params['calendar']), true, false, false);
         } else {
             $all_events = Kronolith::listEvents($startDate, $endDate, $GLOBALS['display_calendars']);
         }
@@ -77,7 +82,7 @@ class Horde_Block_Kronolith_prevmonthlist extends Horde_Block {
             return '<em>' . $all_events->getMessage() . '</em>';
         }
 
-        $html = '<link href="' . Horde::applicationUrl('themes/categoryCSS.php') . '" rel="stylesheet" type="text/css" />';
+        $html = '<link href="' . Horde::applicationUrl('themes/categoryCSS.php', true) . '" rel="stylesheet" type="text/css" />';
 
         /* How many days do we need to check. */
         $days = Date_Calc::dateDiff($startDate->mday, $startDate->month, $startDate->year,
@@ -147,7 +152,7 @@ class Horde_Block_Kronolith_prevmonthlist extends Horde_Block {
                     $html .= '<strong>';
                 }
                 if (isset($event->eventID)) {
-                    $html .= $event->getLink();
+                    $html .= $event->getLink(null, true, null, true);
                 } elseif (isset($this->external)) {
                     $html .= Horde::link(Horde::url($registry->link($this->external . '/show', $event->external_params),
                                                     true), $event->getTitle()) . $event->getTitle() . '</a>';
