@@ -6,7 +6,7 @@ $block_name = _("Calendar Summary");
  * Horde_Block_Kronolith_summary:: Implementation of the Horde_Block API to
  * display a summary of calendar items.
  *
- * $Horde: kronolith/lib/Block/summary.php,v 1.41.2.14 2008/08/21 00:31:03 mrubinsk Exp $
+ * $Horde: kronolith/lib/Block/summary.php,v 1.41.2.18 2009-01-13 22:44:45 mrubinsk Exp $
  *
  * @package Horde_Block
  */
@@ -41,7 +41,13 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
     function _title()
     {
         global $registry;
-        return Horde::link(Horde::url($registry->getInitialPage(), true)) . htmlspecialchars($registry->get('name')) . '</a>';
+
+        if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+            $url_params = array('display_cal' => $this->_params['calendar']);
+        } else {
+            $url_params = array();
+        }
+        return Horde::link(Horde::url(Util::addParameter($registry->getInitialPage(), $url_params), true)) . htmlspecialchars($registry->get('name')) . '</a>';
     }
 
     /**
@@ -75,7 +81,8 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
 
             $all_events = Kronolith::listEvents($startDate,
                                                 $endDate,
-                                                array($this->_params['calendar']));
+                                                array($this->_params['calendar']),
+                                                true, false, false);
         } else {
             $all_events = Kronolith::listEvents($startDate,
                                                 $endDate,
@@ -140,10 +147,13 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
                         $dayname = strftime($prefs->getValue('date_format'),
                                             $day->getStamp());
                     }
+                    $url_params = array('timestamp' => $day->getStamp());
+                    if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+                        $url_params['display_cal'] = $this->_params['calendar'];
+                    }
                     $daylink = Horde::applicationUrl('day.php', true);
-                    $daylink = Util::addParameter($daylink,
-                                                  'timestamp',
-                                                  $day->getStamp());
+                    $daylink = Util::addParameter($daylink, $url_params);
+                    
                     $html .= Horde::link($daylink, sprintf(_("Goto %s"),
                                                            $dayname));
                     $html .= $dayname . '</a></strong></td></tr>';
@@ -199,7 +209,7 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
             return '<em>' . _("No events to display") . '</em>';
         }
 
-        return '<link href="' . Horde::applicationUrl('themes/categoryCSS.php') . '" rel="stylesheet" type="text/css" /><table cellspacing="0" width="100%">' . $html . '</table>';
+        return '<link href="' . Horde::applicationUrl('themes/categoryCSS.php', true) . '" rel="stylesheet" type="text/css" /><table cellspacing="0" width="100%">' . $html . '</table>';
     }
 
 }
