@@ -2,7 +2,7 @@
 /**
  * The Kronolith_Day:: class provides an API for dealing with days.
  *
- * $Horde: kronolith/lib/Day.php,v 1.26.10.1 2005/04/21 11:27:03 selsky Exp $
+ * $Horde: kronolith/lib/Day.php,v 1.26.10.3 2007-12-20 14:12:32 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Kronolith 0.1
@@ -10,7 +10,36 @@
  */
 class Kronolith_Day extends Horde_Date {
 
-    var $hours;
+    /**
+     * How many time slots are we dividing each hour into? Set from user
+     * preferences.
+     *
+     * @var integer
+     */
+    var $_slotsPerHour;
+
+    /**
+     * How many slots do we have per day? Calculated from $_slotsPerHour.
+     *
+     * @see $_slotsPerHour
+     * @var integer
+     */
+    var $_slotsPerDay;
+
+    /**
+     * How many minutes are in each slot? Calculated from $_slotsPerHour.
+     *
+     * @see $_slotsPerHour
+     * @var integer
+     */
+    var $_slotLength;
+
+    /**
+     * Array of slots holding timestamps for each piece of this day.
+     *
+     * @var array
+     */
+    var $slots = array();
 
     function Kronolith_Day($month = null, $day = null, $year = null)
     {
@@ -27,17 +56,16 @@ class Kronolith_Day extends Horde_Date {
         $this->Horde_Date(array('year' => $year, 'month' => $month, 'mday' => $day));
         $this->correct();
 
-        // Make the data array.
-        $this->makeHours();
-    }
+        $this->_slotsPerHour = $GLOBALS['prefs']->getValue('slots_per_hour');
+        if (!$this->_slotsPerHour) {
+            $this->_slotsPerHour = 1;
+        }
+        $this->_slotsPerDay = $this->_slotsPerHour * 24;
+        $this->_slotLength = 60 / $this->_slotsPerHour;
 
-    function makeHours()
-    {
-        $this->hours = array();
-
-        $row = 0;
-        for ($i = 0; $i < 48; $i++) {
-            $this->hours[$i]['timestamp'] = mktime(0, $i * 30, 0, $this->month, $this->mday, $this->year);
+        for ($i = 0; $i < $this->_slotsPerDay; $i++) {
+            $this->slots[$i]['timestamp'] = mktime(0, $i * $this->_slotLength, 0,
+                                                   $this->month, $this->mday, $this->year);
         }
     }
 
@@ -52,9 +80,9 @@ class Kronolith_Day extends Horde_Date {
         return mktime(0, 0, 0, $this->month, $this->mday + 1, $this->year);
     }
 
-    function getStamp()
+    function getStamp($offset = 0)
     {
-        return mktime(0, 0, 0, $this->month, $this->mday, $this->year);
+        return mktime(0, 0, 0, $this->month, ($this->mday + $offset), $this->year);
     }
 
     function isToday()
