@@ -3,7 +3,7 @@
  * Kronolith_Driver defines an API for implementing storage backends for
  * Kronolith.
  *
- * $Horde: kronolith/lib/Driver.php,v 1.116.2.86 2010/04/22 10:56:48 jan Exp $
+ * $Horde: kronolith/lib/Driver.php,v 1.116.2.88 2010-07-27 17:22:49 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jan Schneider <jan@horde.org>
@@ -1054,6 +1054,9 @@ class Kronolith_Event {
         if (!empty($hash['keywords'])) {
             $this->setKeywords(explode(',', $hash['keywords']));
         }
+        if (!empty($hash['private'])) {
+            $this->private = true;
+        }
         if (!empty($hash['start_date'])) {
             $date = explode('-', $hash['start_date']);
             if (empty($hash['start_time'])) {
@@ -1354,7 +1357,9 @@ class Kronolith_Event {
      */
     function exceptionsList()
     {
-        return implode(', ', array_map(array($this, 'exceptionLink'), $this->recurrence->getExceptions()));
+        $exceptions = $this->recurrence->getExceptions();
+        asort($exceptions);
+        return implode(', ', array_map(array($this, 'exceptionLink'), $exceptions));
     }
 
     function getCalendar()
