@@ -3,7 +3,7 @@
  * The Kronolith_Driver_sql:: class implements the Kronolith_Driver
  * API for a SQL backend.
  *
- * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.46 2009/11/11 07:59:18 jan Exp $
+ * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.48 2010-05-13 17:24:33 jan Exp $
  *
  * @author  Luc Saillard <luc.saillard@fr.alcove.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
@@ -241,10 +241,7 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
      */
     function listEvents($startDate = null, $endDate = null, $hasAlarm = false)
     {
-        $endInterval = $startInterval = null;
-        if (!empty($endDate)) {
-            list($endInterval->mday, $endInterval->month, $endInterval->year) = explode('/', Date_Calc::nextDay($endDate->mday, $endDate->month, $endDate->year, '%d/%m/%Y'));
-        }
+        $startInterval = $endInterval = null;
         if (!empty($startDate)) {
             $startInterval = new Horde_Date($startDate);
             if ($startInterval->month == 0) {
@@ -254,6 +251,9 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
                 $startInterval->mday = 1;
             }
         }
+        if (!empty($endDate)) {
+            $endInterval = new Horde_Date($endDate);
+        }
 
         return $this->listEventsConditional($startInterval, $endInterval,
                                             $hasAlarm ? 'event_alarm > ?' : '',
@@ -297,18 +297,18 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             $endInterval->correct();
             $etime = sprintf('%04d-%02d-%02d 00:00:00', $endInterval->year, $endInterval->month, $endInterval->mday);
             $stime = sprintf('%04d-%02d-%02d 00:00:00', $startInterval->year, $startInterval->month, $startInterval->mday);
-            $q .= ' AND ((event_end >= CAST(? as timestamp) AND event_start <= CAST(? as timestamp)) OR (event_recurenddate >= CAST(? as timestamp) AND event_start <= CAST(? as timestamp) AND event_recurtype <> CAST(? as timestamp)))';
+            $q .= ' AND ((event_end >= ? AND event_start <= ?) OR (event_recurenddate >= ? AND event_start <= ? AND event_recurtype <> ?))';
             array_push($values, $stime, $etime, $stime, $etime, HORDE_DATE_RECUR_NONE);
         } elseif (!is_null($startInterval)) {
             $stime = sprintf('%04d-%02d-%02d 00:00:00', $startInterval->year, $startInterval->month, $startInterval->mday);
-            $q .= ' AND ((event_end >= CAST(? as timestamp)) OR (event_recurenddate >= CAST(? as timestamp) AND event_recurtype <> CAST(? as timestamp)))';
+            $q .= ' AND ((event_end >= ?) OR (event_recurenddate >= ? AND event_recurtype <> ?))';
             array_push($values, $stime, $stime, HORDE_DATE_RECUR_NONE);
         } elseif (!is_null($endInterval)) {
             $endInterval = new Horde_Date(array('mday' => $endInterval->mday + 1,
                                                 'month' => $endInterval->month,
                                                 'year' => $endInterval->year));
             $endInterval->correct();
-            $q .= ' AND (event_start <= CAST(? as timestamp))';
+            $q .= ' AND (event_start <= ?)';
             $values[] = sprintf('%04d-%02d-%02d 00:00:00', $endInterval->year, $endInterval->month, $endInterval->mday);
         }
 
