@@ -2,7 +2,7 @@
 /**
  * Free/Busy functionality.
  *
- * $Horde: kronolith/lib/FreeBusy.php,v 1.11.2.7 2009/01/07 13:56:01 jan Exp $
+ * $Horde: kronolith/lib/FreeBusy.php,v 1.11.2.8 2010-02-15 15:38:23 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Kronolith 2.2
@@ -61,6 +61,9 @@ class Kronolith_FreeBusy {
                                          $user ? $user : $share->get('owner'));
         $email = $identity->getValue('from_addr');
         $cn = $identity->getValue('fullname');
+        if (empty($mail) && empty($cn)) {
+            $cn = $user ? $user : $share->get('owner');
+        }
 
         /* Fetch events. */
         $busy = Kronolith::listEvents($startstamp, $endstamp, $calendar);
