@@ -2,7 +2,7 @@
 /**
  * Kronolith external API interface.
  *
- * $Horde: kronolith/lib/api.php,v 1.126.2.64 2009/09/04 10:38:36 jan Exp $
+ * $Horde: kronolith/lib/api.php,v 1.126.2.67 2010-05-09 19:00:32 mrubinsk Exp $
  *
  * This file defines Kronolith's external API interface. Other applications
  * can interact with Kronolith through this API.
@@ -165,27 +165,6 @@ function _kronolith_removeUserData($user)
     /* Remove all events owned by the user in all calendars. */
     $result = $kronolith_driver->removeUserData($user);
 
-    /* Now delete history as well. */
-    $history = &Horde_History::singleton();
-    if (method_exists($history, 'removeByParent')) {
-        $histories = $history->removeByParent('kronolith:' . $user);
-    } else {
-        /* Remove entries 100 at a time. */
-        $all = $history->getByTimestamp('>', 0, array(), 'kronolith:' . $user);
-        if (is_a($all, 'PEAR_Error')) {
-            Horde::logMessage($all, __FILE__, __LINE__, PEAR_LOG_ERR);
-        } else {
-            $all = array_keys($all);
-            while (count($d = array_splice($all, 0, 100)) > 0) {
-                $history->removebyNames($d);
-            }
-        }
-    }
-
-    if (is_a($result, 'PEAR_Error')) {
-        return $result;
-    }
-
     /* Get the user's default share */
     $share = $GLOBALS['kronolith_shares']->getShare($user);
     if (is_a($share, 'PEAR_Error')) {
@@ -933,7 +912,10 @@ function _kronolith_exportCalendar($calendar, $contentType)
 
         require_once 'Horde/iCalendar.php';
         $iCal = new Horde_iCalendar($version);
-        $iCal->setAttribute('X-WR-CALNAME', String::convertCharset($share->get('name'), NLS::getCharset(), 'utf-8'));
+        $iCal->setAttribute('X-WR-CALNAME', String::convertCharset($share->get('name'), NLS::getCharset(), 'UTF-8'));
+        if (strlen($share->get('desc'))) {
+            $iCal->setAttribute('X-WR-CALDESC', String::convertCharset($share->get('desc'), NLS::getCharset(), 'UTF-8'));
+        }
 
         foreach ($events as $id) {
             $event = &$kronolith_driver->getEvent($id);
@@ -1291,6 +1273,9 @@ function _kronolith_listAlarms($time, $user = null)
         return $alarms;
     }
     foreach ($alarms as $calendar => $cal_alarms) {
+        if (!$cal_alarms) {
+            continue;
+        }
         $share = $GLOBALS['kronolith_shares']->getShare($calendar);
         if (is_a($share, 'PEAR_Error')) {
             continue;
